%global pkgname cryptography
%global sum PyCA's cryptography library
%global pkgdesc \
cryptography is a package designed to expose cryptographic primitives \
and recipes to Python developers.

Name:           python3-%{pkgname}
Version:        1.7.2
Release:        3%{?dist}
Summary:        %{sum}

Group:          Development/Libraries
License:        ASL 2.0 or BSD
URL:            https://cryptography.io/en/latest/
Source0:        https://pypi.io/packages/source/c/cryptography/cryptography-%{version}.tar.gz
Patch0:         0001-Drop-minimal-setuptools-and-pytest-version-fron-setu.patch
Patch1:         0002-Disable-unsupported-tests.patch
Patch2:         0003-Refactor-binding-initialization-to-allow-specified-e.patch
Patch3:         0004-Enlarge-_oid2txt-buffer-to-handle-larger-OIDs-3612.patch

# Patch from https://github.com/pyca/cryptography/pull/3328
Patch10:        add_memory_limit.patch

BuildRequires:  openssl-devel

BuildRequires:  python-srpm-macros

%description %{pkgdesc}


%if %{python3_pkgversion} != 3
%package -n  python%{python3_pkgversion}-%{pkgname}
Group:          Development/Libraries
Summary:        %{sum}

BuildRequires:  python%{python3_pkgversion}-devel
BuildRequires:  python%{python3_pkgversion}-pytest
BuildRequires:  python%{python3_pkgversion}-setuptools
BuildRequires:  python%{python3_pkgversion}-pretend
BuildRequires:  python%{python3_pkgversion}-iso8601
BuildRequires:  python%{python3_pkgversion}-cryptography-vectors = %{version}
BuildRequires:  python%{python3_pkgversion}-pyasn1-modules >= 0.1.8
BuildRequires:  python%{python3_pkgversion}-hypothesis
BuildRequires:  python%{python3_pkgversion}-pytz
BuildRequires:  python%{python3_pkgversion}-idna >= 2.0
BuildRequires:  python%{python3_pkgversion}-pyasn1 >= 0.1.8
BuildRequires:  python%{python3_pkgversion}-six >= 1.4.1
BuildRequires:  python%{python3_pkgversion}-cffi >= 1.4.1
%{?python_provide:%python_provide python%{python3_pkgversion}-%{pkgname}}
Requires:       openssl
Requires:       python%{python3_pkgversion}-idna >= 2.0
Requires:       python%{python3_pkgversion}-pyasn1 >= 0.1.8
Requires:       python%{python3_pkgversion}-six >= 1.4.1
Requires:       python%{python3_pkgversion}-cffi >= 1.4.1

%description -n python%{python3_pkgversion}-%{pkgname} %{pkgdesc}
%endif


%if 0%{?with_python3_other}
%package -n  python%{python3_other_pkgversion}-%{pkgname}
Group:          Development/Libraries
Summary:        %{sum}

BuildRequires:  python%{python3_other_pkgversion}-devel
BuildRequires:  python%{python3_other_pkgversion}-pytest
BuildRequires:  python%{python3_other_pkgversion}-setuptools
BuildRequires:  python%{python3_other_pkgversion}-pretend
BuildRequires:  python%{python3_other_pkgversion}-iso8601
BuildRequires:  python%{python3_other_pkgversion}-cryptography-vectors = %{version}
BuildRequires:  python%{python3_other_pkgversion}-pyasn1-modules >= 0.1.8
BuildRequires:  python%{python3_other_pkgversion}-hypothesis
BuildRequires:  python%{python3_other_pkgversion}-pytz
BuildRequires:  python%{python3_other_pkgversion}-idna >= 2.0
BuildRequires:  python%{python3_other_pkgversion}-pyasn1 >= 0.1.8
BuildRequires:  python%{python3_other_pkgversion}-six >= 1.4.1
BuildRequires:  python%{python3_other_pkgversion}-cffi >= 1.4.1
%{?python_provide:%python_provide python%{python3_other_pkgversion}-%{pkgname}}
Requires:       openssl
Requires:       python%{python3_other_pkgversion}-idna >= 2.0
Requires:       python%{python3_other_pkgversion}-pyasn1 >= 0.1.8
Requires:       python%{python3_other_pkgversion}-six >= 1.4.1
Requires:       python%{python3_other_pkgversion}-cffi >= 1.4.1

%description -n python%{python3_other_pkgversion}-%{pkgname} %{pkgdesc}
%endif


%prep
%autosetup -p1 -n cryptography-%{version}


%build
%py3_build
%if 0%{?with_python3_other}
%py3_other_build
%endif


%install
# Actually other *.c and *.h are appropriate
# see https://github.com/pyca/cryptography/issues/1463
find . -name .keep -print -delete

%py3_install
%if 0%{?with_python3_other}
%py3_other_install
%endif


%check
%{__python3} setup.py test
%if 0%{?with_python3_other}
%{__python3_other} setup.py test
%endif


%files -n python%{python3_pkgversion}-%{pkgname}
%doc README.rst docs
%license LICENSE LICENSE.APACHE LICENSE.BSD
%{python3_sitearch}/*

%if 0%{?with_python3_other}
%files -n python%{python3_other_pkgversion}-%{pkgname}
%doc README.rst docs
%license LICENSE LICENSE.APACHE LICENSE.BSD
%{python3_other_sitearch}/*
%endif


%changelog
* Thu Oct 26 2017 Aurelien Bompard <abompard@fedoraproject.org> - 1.7.2-3
- Rebase on 1.7.2-1.el7_4.1
- Add missing Requires.

* Tue Aug 15 2017 Aurelien Bompard <abompard@fedoraproject.org> - 1.7.2-2
- Build the Python3 version on EPEL:
  http://fedoraproject.org/wiki/PackagingDrafts:Python3EPEL

* Wed Feb 15 2017 Christian Heimes <cheimes@redhat.com> - 1.7.2-1
- Update to latest upstream

* Sat Feb 11 2017 Fedora Release Engineering <releng@fedoraproject.org> - 1.7.1-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_26_Mass_Rebuild

* Thu Jan 05 2017 Matěj Cepl <mcepl@redhat.com> - 1.7.1-1
- Update to the latest upstream.
- Add a patch from https://github.com/pyca/cryptography/pull/3328

* Tue Dec 13 2016 Charalampos Stratakis <cstratak@redhat.com> - 1.5.3-5
- Enable tests

* Mon Dec 12 2016 Charalampos Stratakis <cstratak@redhat.com> - 1.5.3-4
- Rebuild for Python 3.6
- Disable python3 tests for now

* Thu Nov 10 2016 Nathaniel McCallum <npmccallum@redhat.com> - 1.5.3-3
- Revert previous change

* Thu Nov 10 2016 Nathaniel McCallum <npmccallum@redhat.com> - 1.5.3-2
- Disable tests on releases earlier than 24

* Mon Nov 07 2016 Nathaniel McCallum <npmccallum@redhat.com> - 1.5.3-1
- Update to v1.5.3
- Update source URL
- Add BR for pytz

* Tue Jul 19 2016 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.3.1-4
- https://fedoraproject.org/wiki/Changes/Automatic_Provides_for_Python_RPM_Packages

* Tue May 10 2016 Nathaniel McCallum <npmccallum@redhat.com> - 1.3.1-3
- Remove versioned setuptools dependency

* Tue May 10 2016 Nathaniel McCallum <npmccallum@redhat.com> - 1.3.1-2
- Make it easier to build on EL7

* Tue May 03 2016 Nathaniel McCallum <npmccallum@redhat.com> - 1.3.1-1
- Update to v1.3.1

* Thu Feb 04 2016 Fedora Release Engineering <releng@fedoraproject.org> - 1.2.1-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_24_Mass_Rebuild

* Mon Jan 11 2016 Nathaniel McCallum <npmccallum@redhat.com> - 1.2.1-2
- Move python-cryptograph => python2-cryptography

* Sat Jan 09 2016 Nathaniel McCallum <npmccallum@redhat.com> - 1.2.1-1
- Update to v1.2.1

* Wed Nov 11 2015 Robert Kuska <rkuska@redhat.com> - 1.1-1
- Update to v1.1

* Wed Nov 04 2015 Robert Kuska <rkuska@redhat.com> - 1.0.2-2
- Rebuilt for Python3.5 rebuild

* Wed Sep 30 2015 Matěj Cepl <mcepl@redhat.com> - 1.0.2-1
- New upstream release (fix #1267548)

* Wed Aug 12 2015 Nathaniel McCallum <npmccallum@redhat.com> - 1.0-1
- New upstream release

* Thu Jun 18 2015 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.9-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_23_Mass_Rebuild

* Thu May 14 2015 Nathaniel McCallum <npmccallum@redhat.com> - 0.9-1
- New upstream release
- Run tests on RHEL
- New deps: python-idna, python-ipaddress

* Fri Apr 17 2015 Nathaniel McCallum <npmccallum@redhat.com> - 0.8.2-1
- New upstream release
- Add python3-pyasn1 Requires (#1211073)

* Tue Apr 14 2015 Matej Cepl <mcepl@redhat.com> - 0.8-2
- Add python-pyasn1 Requires (#1211073)

* Fri Mar 13 2015 Nathaniel McCallum <npmccallum@redhat.com> - 0.8-1
- New upstream release
- Remove upstreamed patch

* Wed Mar 04 2015 Nathaniel McCallum <npmccallum@redhat.com> - 0.7.2-2
- Add python3-cryptography-vectors build requires
- Add python-enum34 requires

* Tue Feb 03 2015 Nathaniel McCallum <npmccallum@redhat.com> - 0.7.2-1
- New upstream release. BSD is now an optional license.
- Fix test running on python3
- Add upstream patch to fix test paths

* Fri Nov 07 2014 Matej Cepl <mcepl@redhat.com> - 0.6.1-2
- Fix requires, for reasons why other development files were not
  eliminated see https://github.com/pyca/cryptography/issues/1463.

* Wed Nov 05 2014 Matej Cepl <mcepl@redhat.com> - 0.6.1-1
- New upstream release.

* Sun Jun 29 2014 Terry Chia <terrycwk1994@gmail.com> 0.4-1
- initial version
